@@ -14,11 +14,13 @@
 
 #include "drivers/lcd.h"
 
-#ifndef bool
-# define bool short
-# define true 1
-# define false 0
+#ifdef HAVE_CONFIG_H
+# include "config.h"
 #endif
+#ifdef HAVE_STDBOOL_H
+# include <stdbool.h>
+#endif
+#include "shared/defines.h"
 
 Driver *
 driver_load(const char *name, const char *filename);
