@@ -24,17 +24,26 @@
 # include "hd44780-lcd2usb.h"
 # include "hd44780-usbtiny.h"
 # include "hd44780-uss720.h"
+# include "hd44780-usb4all.h"
 #endif
 #ifdef HAVE_LIBFTDI
 # include "hd44780-ftdi.h"
 #endif
 #ifdef HAVE_I2C
 # include "hd44780-i2c.h"
+# include "hd44780-piplate.h"
+#endif
+#ifdef HAVE_SPI
+# include "hd44780-spi.h"
+# include "hd44780-pifacecad.h"
 #endif
 #ifdef WITH_ETHLCD
 # include "hd44780-ethlcd.h"
 #endif
-# include "hd44780-usblcd.h"
+#include "hd44780-usblcd.h"
+#ifdef WITH_RASPBERRYPI
+# include "hd44780-rpi.h"
+#endif
 /* add new connection type header files to the correct section above or here */
 
 
@@ -68,6 +77,7 @@ static const ConnectionMapping connectionMapping[] = {
 	{ "lcd2usb",       HD44780_CT_LCD2USB,       IF_TYPE_USB,     hd_init_lcd2usb   },
 	{ "usbtiny",       HD44780_CT_USBTINY,       IF_TYPE_USB,     hd_init_usbtiny   },
 	{ "uss720",        HD44780_CT_USS720,        IF_TYPE_USB,     hd_init_uss720    },
+	{ "usb4all",       HD44780_CT_USB4ALL,       IF_TYPE_USB,     hd_init_usb4all   },
 #endif
 #ifdef HAVE_LIBFTDI
 	{ "ftdi",          HD44780_CT_FTDI,          IF_TYPE_USB,     hd_init_ftdi      },
@@ -75,10 +85,18 @@ static const ConnectionMapping connectionMapping[] = {
 	/* I2C connection types */
 #ifdef HAVE_I2C
 	{ "i2c",           HD44780_CT_I2C,           IF_TYPE_I2C,     hd_init_i2c       },
+        { "piplate",       HD44780_CT_PIPLATE,       IF_TYPE_I2C,     hd_init_i2c_piplate },
+#endif
+#ifdef HAVE_SPI
+	{ "spi",           HD44780_CT_SPI,           IF_TYPE_SPI,     hd_init_spi       },
+	{ "pifacecad",     HD44780_CT_PIFACECAD,     IF_TYPE_SPI,     hd_init_pifacecad },
 #endif
 	/* TCP socket connection types */
 #ifdef WITH_ETHLCD
 	{ "ethlcd",        HD44780_CT_ETHLCD,        IF_TYPE_TCP,     hd_init_ethlcd    },
+#endif
+#ifdef WITH_RASPBERRYPI
+	{ "raspberrypi",   HD44780_CT_RASPBERRYPI,   IF_TYPE_PARPORT,  hd_init_rpi      },
 #endif
 	/* add new connection types in the correct section above or here */
 
