@@ -8,10 +8,10 @@
  * to form a 16x8 display.
  *
  * To add support for additional HD44780 connections:
- * \li Add a connection type and mapping to hd44780-drivers.h
- * \li Call your initialization routine
- * \li Create the low-level driver (use hd44780-ext8bit.c as a starting point)
- * \li Modify the makefile
+ * - Add a connection type and mapping to hd44780-drivers.h
+ * - Call your initialization routine
+ * - Create the low-level driver (use hd44780-ext8bit.c as a starting point)
+ * - Modify the makefile
  */
 
 /*-
@@ -427,6 +427,13 @@ HD44780_init(Driver *drvthis)
  			 (p->have_output?" out":"")
  			);
  		break;
+ 	  case IF_TYPE_SPI:
+ 		sprintf(buf, "SPI %s%s%s",
+ 			 (p->have_backlight?" bl":""),
+ 			 (p->have_keypad?" key":""),
+ 			 (p->have_output?" out":"")
+ 			);
+ 		break;
  	  case IF_TYPE_TCP:
  		sprintf(buf, "TCP %s%s%s",
  			 (p->have_backlight?" bl":""),
@@ -456,7 +463,7 @@ HD44780_init(Driver *drvthis)
  * - set display on & cursor off, not blinking,
  * - set output mode to left-to-right & turn off display scolling
  * - clear display & move cursor home
- * .
+ *
  * \param p       Pointer to PrivateData structure.
  * \param if_bit  Command bits for 4- resp. 8-bit mode
  */
@@ -688,8 +695,7 @@ HD44780_flush(Driver *drvthis)
 					drawing = 1;
 					HD44780_position(drvthis,x,y);
 				}
-				p->hd44780_functions->senddata(p, dispID, RS_DATA,
-							       available_charmaps[p->charmap].charmap[*sp]);
+				p->hd44780_functions->senddata(p, dispID, RS_DATA, *sp);
 				p->hd44780_functions->uPause(p, 40);  /* Minimum exec time for all commands */
 				*sq = *sp;	/* Update backing store */
 				count++;
@@ -754,7 +760,8 @@ HD44780_chr(Driver *drvthis, int x, int y, char ch)
 	x--;
 
 	if ((x >= 0) && (y >= 0) && (x < p->width) && (y < p->height))
-		p->framebuf[(y * p->width) + x] = ch;
+		p->framebuf[(y * p->width) + x] =
+			available_charmaps[p->charmap].charmap[(unsigned char) ch];
 }
 
 
@@ -780,7 +787,8 @@ HD44780_string(Driver *drvthis, int x, int y, const char string[])
 
 	for (i = 0; (string[i] != '\0') && (x < p->width); i++, x++) {
 		if (x >= 0)	/* no write left of left border */
-			p->framebuf[(y * p->width) + x] = string[i];
+			p->framebuf[(y * p->width) + x] =
+				available_charmaps[p->charmap].charmap[(unsigned char) string[i]];
 	}
 }
 
@@ -909,15 +917,6 @@ HD44780_vbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	/*
-	 * x and y are the start position of the bar.
-	 * The bar by default grows in the 'up' direction
-	 * (other direction not yet implemented).
-	 * len is the number of characters that the bar is long at 100%
-	 * promille is the number of promilles (0..1000) that the bar should
-	 * be filled.
-	 */
-
 	if (p->ccmode != vbar) {
 		unsigned char vBar[p->cellheight];
 		int i;
@@ -957,14 +956,6 @@ HD44780_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	/*
-	 * x and y are the start position of the bar.
-	 * The bar by default grows in the 'right' direction
-	 * (other direction not yet implemented).
-	 * len is the number of characters that the bar is long at 100%
-	 * promille is the number of promilles (0..1000) that the bar should be filled.
-	 */
-
 	if (p->ccmode != hbar) {
 		unsigned char hBar[p->cellheight];
 		int i;
@@ -973,7 +964,7 @@ HD44780_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 			/* Not supported(yet) */
 			report(RPT_WARNING, "%s: hbar: cannot combine two modes using user-defined characters",
 			      drvthis->name);
-		return;
+			return;
 		}
 
 		p->ccmode = hbar;
@@ -1038,7 +1029,7 @@ HD44780_get_free_chars(Driver *drvthis)
  * Define a custom character and write it to the LCD.
  * \param drvthis  Pointer to driver structure.
  * \param n        Custom character to define [0 - (NUM_CCs-1)].
- * \param dat      Array of 8(=cellheight) bytes, each representing a pixel row
+ * \param dat      Array of 8 (=cellheight) bytes, each representing a pixel row
  *                 starting from the top to bottom.
  *                 The bits in each byte represent the pixels where the LSB
  *                 (least significant bit) is the rightmost pixel in each pixel row.
@@ -1062,7 +1053,7 @@ HD44780_set_char(Driver *drvthis, int n, unsigned char *dat)
 			letter = dat[row] & mask;
 
 		if (p->cc[n].cache[row] != letter)
-			p->cc[n].clean = 0;	 /* only mark dirty if really different */
+			p->cc[n].clean = 0;	/* only mark dirty if really different */
 		p->cc[n].cache[row] = letter;
 	}
 }
@@ -1080,6 +1071,8 @@ HD44780_set_char(Driver *drvthis, int n, unsigned char *dat)
 MODULE_EXPORT int
 HD44780_icon(Driver *drvthis, int x, int y, int icon)
 {
+	PrivateData *p = (PrivateData *) drvthis->private_data;
+
 	static unsigned char heart_open[] =
 		{ b__XXXXX,
 		  b__X_X_X,
@@ -1116,26 +1109,6 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b___XXX_,
 		  b____X__,
 		  b_______ };
-	/*-
-	static unsigned char arrow_left[] =
-		{ b_______,
-		  b____X__,
-		  b___X___,
-		  b__XXXXX,
-		  b___X___,
-		  b____X__,
-		  b_______,
-		  b_______ };
-	static unsigned char arrow_right[] =
-		{ b_______,
-		  b____X__,
-		  b_____X_,
-		  b__XXXXX,
-		  b_____X_,
-		  b____X__,
-		  b_______,
-		  b_______ };
-	*/
 	static unsigned char checkbox_off[] =
 		{ b_______,
 		  b_______,
@@ -1163,35 +1136,6 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X_X_X,
 		  b__XXXXX,
 		  b_______ };
-	/*-
-	static unsigned char selector_left[] =
-		{ b___X___,
-		  b___XX__,
-		  b___XXX_,
-		  b___XXXX,
-		  b___XXX_,
-		  b___XX__,
-		  b___X___,
-		  b_______ };
-	static unsigned char selector_right[] =
-		{ b_____X_,
-		  b____XX_,
-		  b___XXX_,
-		  b__XXXX_,
-		  b___XXX_,
-		  b____XX_,
-		  b_____X_,
-		  b_______ };
-	static unsigned char ellipsis[] =
-		{ b_______,
-		  b_______,
-		  b_______,
-		  b_______,
-		  b_______,
-		  b_______,
-		  b__X_X_X,
-		  b_______ };
-	*/
 	static unsigned char block_filled[] =
 		{ b__XXXXX,
 		  b__XXXXX,
@@ -1202,20 +1146,59 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__XXXXX,
 		  b__XXXXX };
 
-	/* Yes I know, this is a VERY BAD implementation */
+	/* Icons from CGROM will always work */
 	switch (icon) {
-		case ICON_BLOCK_FILLED:
-			HD44780_set_char(drvthis, 6, block_filled);
-			HD44780_chr(drvthis, x, y, 6);
-			break;
-		case ICON_HEART_FILLED:
-			HD44780_set_char(drvthis, 0, heart_filled);
+	    case ICON_ARROW_LEFT:
+		HD44780_chr(drvthis, x, y, 0x1B);
+		return 0;
+	    case ICON_ARROW_RIGHT:
+		HD44780_chr(drvthis, x, y, 0x1A);
+		return 0;
+	}
+
+	/* The full block works except if ccmode=bignum */
+	if (icon == ICON_BLOCK_FILLED) {
+		if (p->ccmode != bignum) {
+			HD44780_set_char(drvthis, 0, block_filled);
 			HD44780_chr(drvthis, x, y, 0);
-			break;
-		case ICON_HEART_OPEN:
-			HD44780_set_char(drvthis, 0, heart_open);
-			HD44780_chr(drvthis, x, y, 0);
-			break;
+			return 0;
+		}
+		else {
+			return -1;
+		}
+	}
+
+	/* The heartbeat icons do not work in bignum and vbar mode */
+	if ((icon == ICON_HEART_FILLED) || (icon == ICON_HEART_OPEN)) {
+		if ((p->ccmode != bignum) && (p->ccmode != vbar)) {
+			switch (icon) {
+			    case ICON_HEART_FILLED:
+				HD44780_set_char(drvthis, 7, heart_filled);
+				HD44780_chr(drvthis, x, y, 7);
+				return 0;
+			    case ICON_HEART_OPEN:
+				HD44780_set_char(drvthis, 7, heart_open);
+				HD44780_chr(drvthis, x, y, 7);
+				return 0;
+			}
+		}
+		else {
+			return -1;
+		}
+	}
+
+	/* All other icons work only in the standard or icon ccmode */
+	if (p->ccmode != icons) {
+		if (p->ccmode != standard) {
+			/* Not supported (yet) */
+			report(RPT_WARNING, "%s: num: cannot combine two modes using user-defined characters",
+					drvthis->name);
+			return -1;
+		}
+		p->ccmode = icons;
+	}
+
+	switch (icon) {
 		case ICON_ARROW_UP:
 			HD44780_set_char(drvthis, 1, arrow_up);
 			HD44780_chr(drvthis, x, y, 1);
@@ -1224,12 +1207,6 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 			HD44780_set_char(drvthis, 2, arrow_down);
 			HD44780_chr(drvthis, x, y, 2);
 			break;
-		case ICON_ARROW_LEFT:
-			HD44780_chr(drvthis, x, y, 0x7F);
-			break;
-		case ICON_ARROW_RIGHT:
-			HD44780_chr(drvthis, x, y, 0x7E);
-			break;
 		case ICON_CHECKBOX_OFF:
 			HD44780_set_char(drvthis, 3, checkbox_off);
 			HD44780_chr(drvthis, x, y, 3);
@@ -1263,7 +1240,7 @@ HD44780_get_key(Driver *drvthis)
 	char *keystr = NULL;
 	struct timeval curr_time, time_diff;
 
-	/* return "no key pressed" if required functions mission or input disabled */
+	/* return "no key pressed" if required function is missing or input disabled */
 	if ((!p->have_keypad) || (p->hd44780_functions->scankeypad == NULL))
 		return NULL;
 
@@ -1323,8 +1300,8 @@ HD44780_get_key(Driver *drvthis)
  *
  * The returned scancode consists of 4 bits for the row and 4 bits for the
  * column of the keypad. This allows for a 16x16 matrix keypad in theory, but
- * on a parallel port we are limited to a 11x5 matrix (8 data + 3 control pins
- * - excluding one for EN1, 5 status pins).
+ * on a parallel port we are limited to a 11x5 matrix (8 data + 3 control
+ * pins - excluding one for EN1, 5 status pins).
  *
  * Note that a connection type may support even less rows/columns!
  *
