@@ -29,6 +29,10 @@
  *		 2007, Peter Marschall
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,7 +42,6 @@
 #include "shared/defines.h"
 
 #include "drivers.h"
-
 #include "screen.h"
 #include "screenlist.h"
 #include "widget.h"
@@ -257,7 +260,7 @@ render_frame(LinkedList *list,
 			case WID_VBAR:			  /* FIXME:  Vbars don't work in frames! */
 				render_vbar(w, left, top, right, bottom);
 				break;
-			case WID_ICON:			  /* FIXME:  Vbars don't work in frames! */
+			case WID_ICON:			  /* FIXME:  Icons don't work in frames! */
 				drivers_icon(w->x, w->y, w->length);
 				break;
 			case WID_TITLE:			  /* FIXME:  Doesn't work quite right in frames... */
@@ -488,11 +491,11 @@ render_scroller(Widget *w, int left, int top, int right, int bottom, long timer)
 
 					if (w->speed > 0) {
 						necessaryTimeUnits = length * w->speed;
-						offset = (timer % (length * w->speed)) / w->speed;
+						offset = (timer % necessaryTimeUnits) / w->speed;
 					}
 					else if (w->speed < 0) {
 						necessaryTimeUnits = length / (w->speed * -1);
-						offset = (timer % (length / (w->speed * -1))) * w->speed * -1;
+						offset = (timer % necessaryTimeUnits) * w->speed * -1;
 					}
 					else {
 						offset = 0;
@@ -529,7 +532,7 @@ render_scroller(Widget *w, int left, int top, int right, int bottom, long timer)
 
 					if (w->speed > 0) {
 						necessaryTimeUnits = effLength * w->speed;
-						if (((timer / (effLength * w->speed)) % 2) == 0) {
+						if (((timer / necessaryTimeUnits) % 2) == 0) {
 							/* wiggle one way */
 							offset = (timer % (effLength * w->speed))
 								 / w->speed;
@@ -543,7 +546,7 @@ render_scroller(Widget *w, int left, int top, int right, int bottom, long timer)
 					}
 					else if (w->speed < 0) {
 						necessaryTimeUnits = effLength / (w->speed * -1);
-						if (((timer / (effLength / (w->speed * -1))) % 2) == 0) {
+						if (((timer / necessaryTimeUnits) % 2) == 0) {
 							offset = (timer % (effLength / (w->speed * -1)))
 								 * w->speed * -1;
 						}
@@ -600,26 +603,26 @@ render_scroller(Widget *w, int left, int top, int right, int bottom, long timer)
 						/*debug(RPT_DEBUG, "length: %d sw: %d lines req: %d  avail lines: %d  effLines: %d ",length,screen_width,lines_required,available_lines,effLines);*/
 						if (w->speed > 0) {
 							necessaryTimeUnits = effLines * w->speed;
-							if (((timer / (effLines * w->speed)) % 2) == 0) {
+							if (((timer / necessaryTimeUnits) % 2) == 0) {
 								/*debug(RPT_DEBUG, "up ");*/
-								begin = (timer % (effLines * w->speed))
+								begin = (timer % (necessaryTimeUnits))
 									 / w->speed;
 							}
 							else {
 								/*debug(RPT_DEBUG, "down ");*/
-								begin = (((timer % (effLines * w->speed))
-									 - (effLines * w->speed) + 1) / w->speed)
+								begin = (((timer % necessaryTimeUnits)
+									 - necessaryTimeUnits + 1) / w->speed)
 									 * -1;
 							}
 						}
 						else if (w->speed < 0) {
 							necessaryTimeUnits = effLines / (w->speed * -1);
-							if (((timer / (effLines / (w->speed * -1))) % 2) == 0) {
-								begin = (timer % (effLines / (w->speed * -1)))
+							if (((timer / necessaryTimeUnits) % 2) == 0) {
+								begin = (timer % necessaryTimeUnits)
 									 * w->speed * -1;
 							}
 							else {
-								begin = (((timer % (effLines / (w->speed * -1)))
+								begin = (((timer % necessaryTimeUnits)
 									 * w->speed * -1) - effLines + 1)
 									 * -1;
 							}
